### -*- coding: utf-8 -*- ####################################################
##############################################################################
#
# Copyright (c) 2008-2010 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

__docformat__ = "restructuredtext"

# import standard packages

# import Zope3 interfaces
from zope.intid.interfaces import IIntIds
from zope.traversing.interfaces import TraversalError

# import local interfaces

# import Zope3 packages
from zope.component import getUtility
from zope.traversing import namespace

# import local packages


class UniqueIDNamespaceTraverser(namespace.view):
    """++oid++ namespace traverser"""

    def traverse(self, name, ignored):
        intids = getUtility(IIntIds)
        try:
            return intids.getObject(int(name))
        except:
            raise TraversalError('++oid++%s' % name)



### -*- coding: utf-8 -*- ####################################################
##############################################################################
#
# Copyright (c) 2008-2013 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

__docformat__ = "restructuredtext"

# import standard packages

# import Zope3 interfaces
# most interfaces have moved to ZTFY.baseskin package; please use them directly...
# following imports are kept only for compatibility reasons
from ztfy.baseskin.interfaces.container import *

# import local interfaces

# import Zope3 packages
from zope.interface import Interface

# import local packages


class IContainerAddFormMenuTarget(Interface):
    """Marker interface for base add form menu item"""


class IMainContentAddFormMenuTarget(IContainerAddFormMenuTarget):
    """Marker interface for main content add form menu item"""
